==> billogram-foundation-3.11.1.tgz: package/modules/components/dropdown/DropdownContainer.jest.js <==
import React from 'react';
import ReactDOM from 'react-dom';
import TestUtils from 'react-addons-test-utils';
import purebem from 'purebem';
import { Provider } from 'react-redux';

import Dropdown from './Dropdown';
import DropdownContainer, { changeType, collapseType, expandType } from './DropdownContainer';

import dropdownChange from './redux/dropdownChange';
import dropdownCollapse from './redux/dropdownCollapse';
import dropdownExpand from './redux/dropdownExpand';
import dropdownState from './redux/dropdownState';
import dropdownValueOptionState from './option-value/dropdownValueOptionState';

import createStore from '../../test-utils/createStore';


const block = purebem.of('test-dropdown');
// Used to find options to interact with. Far from ideal, but at least
// the tests will fail if the style is refactored.
const optionElement = block('option');

const TestDropdown = Dropdown({
    block,
    displayName: 'TestDropdown'
});

const TestDropdownContainer = DropdownContainer({
    Component: TestDropdown
});

const path = 'option';
const root = 'test';
const actionTypePrefix = 'TEST-DROPDOWN';

test('should dispatch change event when clicking new option', () => {
    const store = createStore({
        test: {
            option: dropdownState({
                expanded: true,
                options: [
                    dropdownValueOptionState({ text: 'A', value: 'a' }),
                    dropdownValueOptionState({ text: 'B', value: 'b' }),
                    dropdownValueOptionState({ text: 'C', value: 'c' })
                ]
            })
        }
    });

    const provider = TestUtils.renderIntoDocument(
        <Provider store={ store }>
            <TestDropdownContainer
                actionTypePrefix={ actionTypePrefix }
                customActionMetadata={ { index: 1 } }
                path={ path }
                root={ root } />
        </Provider>
    );

    const options = TestUtils.scryRenderedDOMComponentsWithClass(provider, optionElement);
    expect(options.length).toBe(3);

    TestUtils.Simulate.click(ReactDOM.findDOMNode(options[1]));

    const actions = store.getState().actions;

    expect(actions.length).toBe(2); // change, and collapse
    expect(actions[0]).toEqual(dropdownChange({
        custom: { index: 1 },
        path,
        root,
        type: changeType(actionTypePrefix),
        value: 'b'
    }));
});

test('should dispatch expand event when clicked and collapsed', () => {
    const store = createStore({
        test: {
            option: dropdownState({
                options: [
                    dropdownValueOptionState()
                ]
            })
        }
    });

    const provider = TestUtils.renderIntoDocument(
        <Provider store={ store }>
            <TestDropdownContainer
                actionTypePrefix={ actionTypePrefix }
                path={ path }
                root={ root } />
        </Provider>
    );

    const container = TestUtils.findRenderedComponentWithType(provider, TestDropdownContainer);
    const node = ReactDOM.findDOMNode(container);

    TestUtils.Simulate.click(node);

    const actions = store.getState().actions;

    expect(actions.length).toBe(1);
    expect(actions[0]).toEqual(dropdownExpand({
        path,
        root,
        type: expandType(actionTypePrefix)
    }));
});

test('should dispatch collapse event when clicked and expanded', () => {
    const store = createStore({
        test: {
            option: dropdownState({
                expanded: true,
                options: [
                    dropdownValueOptionState()
                ]
            })
        }
    });

    const provider = TestUtils.renderIntoDocument(
        <Provider store={ store }>
            <TestDropdownContainer
                actionTypePrefix={ actionTypePrefix }
                path={ path }
                root={ root } />
        </Provider>
    );


    const container = TestUtils.findRenderedComponentWithType(provider, TestDropdownContainer);
    const node = ReactDOM.findDOMNode(container);

    TestUtils.Simulate.click(node);

    const actions = store.getState().actions;

    expect(actions.length).toBe(1);
    expect(actions[0]).toEqual(dropdownCollapse({
        path,
        root,
        type: collapseType(actionTypePrefix)
    }));
});

==> billogram-foundation-3.12.0.tgz: package/modules/components/dropdown/DropdownContainer.jest.js <==
import React from 'react';
import purebem from 'purebem';
import { Provider } from 'react-redux';
import { mount } from 'enzyme';

import Dropdown from './Dropdown';
import DropdownContainer, { changeType, collapseType, expandType } from './DropdownContainer';

import dropdownChange from './redux/dropdownChange';
import dropdownCollapse from './redux/dropdownCollapse';
import dropdownExpand from './redux/dropdownExpand';
import dropdownState from './redux/dropdownState';
import dropdownValueOptionState from './option-value/dropdownValueOptionState';

import createStore from '../../test-utils/createStore';


const TestDropdown = Dropdown({
    block: purebem.of('test-dropdown'),
    displayName: 'TestDropdown'
});

const TestDropdownContainer = DropdownContainer({
    Component: TestDropdown
});

const path = 'option';
const root = 'test';
const actionTypePrefix = 'TEST-DROPDOWN';

test('should dispatch change event when clicking new option', () => {
    const store = createStore({
        test: {
            option: dropdownState({
                expanded: true,
                options: [
                    dropdownValueOptionState({ text: 'A', value: 'a' }),
                    dropdownValueOptionState({ text: 'B', value: 'b' }),
                    dropdownValueOptionState({ text: 'C', value: 'c' })
                ]
            })
        }
    });

    const provider = mount(
        <Provider store={ store }>
            <TestDropdownContainer
                actionTypePrefix={ actionTypePrefix }
                customActionMetadata={ { index: 1 } }
                path={ path }
                root={ root } />
        </Provider>
    );


    const options = provider.find('TestDropdownValueOption');
    expect(options.length).toBe(3);

    options.at(1).simulate('click');

    const actions = store.getState().actions;

    expect(actions.length).toBe(2); // change, and collapse
    expect(actions[0]).toEqual(dropdownChange({
        custom: { index: 1 },
        path,
        root,
        type: changeType(actionTypePrefix),
        value: 'b'
    }));
});

test('should dispatch expand event when clicked and collapsed', () => {
    const store = createStore({
        test: {
            option: dropdownState({
                options: [
                    dropdownValueOptionState()
                ]
            })
        }
    });

    const provider = mount(
        <Provider store={ store }>
            <TestDropdownContainer
                actionTypePrefix={ actionTypePrefix }
                path={ path }
                root={ root } />
        </Provider>
    );

    provider.find(TestDropdownContainer).simulate('click');

    const actions = store.getState().actions;

    expect(actions.length).toBe(1);
    expect(actions[0]).toEqual(dropdownExpand({
        path,
        root,
        type: expandType(actionTypePrefix)
    }));
});

test('should dispatch collapse event when clicked and expanded', () => {
    const store = createStore({
        test: {
            option: dropdownState({
                expanded: true,
                options: [
                    dropdownValueOptionState()
                ]
            })
        }
    });

    const provider = mount(
        <Provider store={ store }>
            <TestDropdownContainer
                actionTypePrefix={ actionTypePrefix }
                path={ path }
                root={ root } />
        </Provider>
    );

    provider.find(TestDropdownContainer).simulate('click');

    const actions = store.getState().actions;

    expect(actions.length).toBe(1);
    expect(actions[0]).toEqual(dropdownCollapse({
        path,
        root,
        type: collapseType(actionTypePrefix)
    }));
});
